SpeedrunAPI
===
A library for working with speedrun.coms API

Docs: 'https://speedrunapi.readthedocs.io'
<br>
The docs should contain all the nessiasary info on how to use the library, The docs should go into depth about most of the functions of the library.

Version: 0.6.0
```python
pip install speedrunapi
```

*This library is licenced under the MIT licence.

## If you have any questions or suggestions please feel free to contact me about them, for issues please report them on the project repository